@@ -1,19 +1,25 @@
+#[cfg(feature = "pgp-commands")]
+use email::account::CmdsPgpConfig;
+#[cfg(feature = "pgp-gpg")]
+use email::account::GpgConfig;
+#[cfg(feature = "pgp-native")]
+use email::account::{NativePgpConfig, NativePgpSecretKey, SignedSecretKey};
 #[cfg(feature = "notmuch-backend")]
-use pimalaya_email::backend::NotmuchConfig;
+use email::backend::NotmuchConfig;
 #[cfg(feature = "imap-backend")]
-use pimalaya_email::backend::{ImapAuthConfig, ImapConfig};
+use email::backend::{ImapAuthConfig, ImapConfig};
 #[cfg(feature = "smtp-sender")]
-use pimalaya_email::sender::{SmtpAuthConfig, SmtpConfig};
-use pimalaya_email::{
-    account::{OAuth2Config, OAuth2Method, OAuth2Scopes, PasswdConfig},
+use email::sender::{SmtpAuthConfig, SmtpConfig};
+use email::{
+    account::{OAuth2Config, OAuth2Method, OAuth2Scopes, PasswdConfig, PgpConfig},
     backend::{BackendConfig, MaildirConfig},
     email::{EmailHooks, EmailTextPlainFormat},
     folder::sync::FolderSyncStrategy,
     sender::{SenderConfig, SendmailConfig},
 };
-use pimalaya_keyring::Entry;
-use pimalaya_process::{Cmd, Pipeline, SingleCmd};
-use pimalaya_secret::Secret;
+use keyring::Entry;
+use process::{Cmd, Pipeline, SingleCmd};
+use secret::Secret;
 use serde::{ser::SerializeSeq, Deserialize, Serialize, Serializer};
 use std::{collections::HashSet, ops::Deref, path::PathBuf};
 
@@ -362,10 +368,18 @@ pub enum SmtpOAuth2ScopesDef {
 #[derive(Clone, Debug, Eq, PartialEq, Serialize, Deserialize)]
 #[serde(remote = "SendmailConfig", rename_all = "kebab-case")]
 pub struct SendmailConfigDef {
-    #[serde(rename = "sendmail-cmd", with = "CmdDef")]
+    #[serde(
+        rename = "sendmail-cmd",
+        with = "CmdDef",
+        default = "sendmail_default_cmd"
+    )]
     cmd: Cmd,
 }
 
+fn sendmail_default_cmd() -> Cmd {
+    Cmd::from("/usr/sbin/sendmail")
+}
+
 /// Represents the email hooks. Useful for doing extra email
 /// processing before or after sending it.
 #[derive(Clone, Debug, Default, Eq, PartialEq, Serialize, Deserialize)]
@@ -387,3 +401,69 @@ pub enum FolderSyncStrategyDef {
     #[serde(alias = "ignore")]
     Exclude(HashSet<String>),
 }
+
+#[derive(Clone, Debug, Default, Eq, PartialEq, Serialize, Deserialize)]
+#[serde(remote = "PgpConfig", tag = "backend", rename_all = "kebab-case")]
+pub enum PgpConfigDef {
+    #[default]
+    None,
+    #[cfg(feature = "pgp-commands")]
+    #[serde(with = "CmdsPgpConfigDef", alias = "commands")]
+    Cmds(CmdsPgpConfig),
+    #[cfg(feature = "pgp-gpg")]
+    #[serde(with = "GpgConfigDef")]
+    Gpg(GpgConfig),
+    #[cfg(feature = "pgp-native")]
+    #[serde(with = "NativePgpConfigDef")]
+    Native(NativePgpConfig),
+}
+
+#[cfg(feature = "pgp-gpg")]
+#[derive(Clone, Debug, Default, Eq, PartialEq, Serialize, Deserialize)]
+#[serde(remote = "GpgConfig", rename_all = "kebab-case")]
+pub struct GpgConfigDef;
+
+#[cfg(feature = "pgp-commands")]
+#[derive(Clone, Debug, Default, Eq, PartialEq, Serialize, Deserialize)]
+#[serde(remote = "CmdsPgpConfig", rename_all = "kebab-case")]
+pub struct CmdsPgpConfigDef {
+    #[serde(default, with = "OptionCmdDef")]
+    encrypt_cmd: Option<Cmd>,
+    #[serde(default)]
+    encrypt_recipient_fmt: Option<String>,
+    #[serde(default)]
+    encrypt_recipients_sep: Option<String>,
+    #[serde(default, with = "OptionCmdDef")]
+    decrypt_cmd: Option<Cmd>,
+    #[serde(default, with = "OptionCmdDef")]
+    sign_cmd: Option<Cmd>,
+    #[serde(default, with = "OptionCmdDef")]
+    verify_cmd: Option<Cmd>,
+}
+
+#[cfg(feature = "pgp-native")]
+#[derive(Clone, Debug, Default, Eq, PartialEq, Serialize, Deserialize)]
+#[serde(remote = "NativePgpConfig", rename_all = "kebab-case")]
+pub struct NativePgpConfigDef {
+    #[serde(default, with = "NativePgpSecretKeyDef")]
+    secret_key: NativePgpSecretKey,
+    #[serde(default, with = "SecretDef")]
+    secret_key_passphrase: Secret,
+    #[serde(default = "NativePgpConfig::default_wkd")]
+    wkd: bool,
+    #[serde(default = "NativePgpConfig::default_key_servers")]
+    key_servers: Vec<String>,
+}
+
+#[cfg(feature = "pgp-native")]
+#[derive(Clone, Debug, Default, Eq, PartialEq, Serialize, Deserialize)]
+#[serde(remote = "NativePgpSecretKey", rename_all = "kebab-case")]
+pub enum NativePgpSecretKeyDef {
+    #[default]
+    None,
+    #[serde(skip)]
+    Raw(SignedSecretKey),
+    Path(PathBuf),
+    #[serde(with = "EntryDef")]
+    Keyring(Entry),
+}
