@@ -3,7 +3,7 @@
 //! This module gathers all IMAP handlers triggered by the CLI.
 
 use anyhow::Result;
-use pimalaya_email::backend::ImapBackend;
+use email::backend::ImapBackend;
 
 pub async fn notify(imap: &mut ImapBackend, folder: &str, keepalive: u64) -> Result<()> {
     imap.notify(keepalive, folder).await?;
