@@ -1,5 +1,4 @@
 use anyhow::{Context, Result};
-use pimalaya_email::email::Tpl;
 
 use crate::printer::WriteColor;
 
@@ -20,10 +19,3 @@ impl Print for String {
         Ok(writer.reset()?)
     }
 }
-
-impl Print for Tpl {
-    fn print(&self, writer: &mut dyn WriteColor) -> Result<()> {
-        self.as_str().print(writer)?;
-        Ok(writer.reset()?)
-    }
-}
